@@ -67,7 +67,7 @@ impl<'a> COMPLETED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -630,7 +630,7 @@ impl R {
     #[doc = "Bit 0 - Controller Complted a Transaction"]
     #[inline(always)]
     pub fn completed(&self) -> COMPLETED_R {
-        COMPLETED_R::new(self.bits != 0)
+        COMPLETED_R::new((self.bits & 0x01) != 0)
     }
     #[doc = "Bit 1 - Controller is Idle"]
     #[inline(always)]
