@@ -67,7 +67,7 @@ impl<'a> PORTA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -533,7 +533,7 @@ impl R {
     #[doc = "Bit 0 - Enable PORTA clock"]
     #[inline(always)]
     pub fn porta(&self) -> PORTA_R {
-        PORTA_R::new(self.bits != 0)
+        PORTA_R::new((self.bits & 0x01) != 0)
     }
     #[doc = "Bit 1 - Enable PORTB clock"]
     #[inline(always)]
